<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="14"/>
        <source>OpenSSH Authentication Passphrase request</source>
        <translation>Pedido de palavra-passe de autenticação OpenSSH</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="20"/>
        <source>Enter your SSH passphrase for request:</source>
        <translation>Digite a palavra-passe SSH para o pedido:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="52"/>
        <source>unknown request</source>
        <translation>pedido desconhecido</translation>
    </message>
</context>
</TS>
